\name{CombinedPlot} 

\alias{CombinedPlot}
\alias{CombinedPlot,RolexaRun-method}
\alias{ChannelHistogram}
\alias{ChannelHistogram,SolexaIntensity-method}
\title{Diagnostic plots}
\description{Generate plots to visualy assess the quality of select colonies
  or sequencing cycles}
\usage{
\S4method{CombinedPlot}{RolexaRun}(run=Rolexa.env, int, seq, scores, colonies = 1:4, par = list())
CombinedPlot(run,...)
\S4method{ChannelHistogram}{SolexaIntensity}(int, cycles = c(1,18,36),
threemodes = FALSE, par = list())
ChannelHistogram(int,...)
}
\arguments{
  \item{run}{a \code{\link[=RolexaRun-class]{RolexaRun}} object defining the run parameters}
  \item{int}{a \code{\link[ShortRead:SolexaIntensity-class]{SolexaIntensity}}
    object}
  \item{seq}{a \code{\link[ShortRead:ShortRead-class]{ShortRead}}
    object}
  \item{scores}{a matrix of base quality scores (one column per base,
    one row per sequence)}
  \item{cycles}{the list of cycles to plot}
  \item{colonies}{the list of rows to select for plotting}
  \item{threemodes}{fit and plot a mixture of 3 gaussians (2 by default)}
  \item{par}{parameters for the plotting function}
  \item{\dots}{additional arguments, ignored}
}
\details{\code{CombinedPlot} creates one plot for each selected colony
  with the sequence along the \code{x} axis, the four intensities
  plotted as barplots above each base and the quality scores as a line
  plot below the sequence.

  \code{ChannelHistogram} plots histograms and signal-noise
  thresholds for each of the four intensity channels on selected
  cycles. Fits to 2 or 3 gaussians are overlaid on the histograms.}
\references{Probabilistic base calling of Solexa sequencing data,
  BMC Bioinformatics 2008, 9:431}
\author{Jacques Rougemont, Arnaud Amzallag, Christian Iseli, Laurent Farinelli, Ioannis Xenarios, Felix Naef}
\examples{
path = SolexaPath(system.file("extdata", package="ShortRead"))
rolenv = SetModel(idsep="_")
int = readIntensities(path,pattern="s_1_0001",withVariability=FALSE)
seq = CombineFastQ(run=rolenv,path=path)
CombinedPlot(run=rolenv,int=int,seq=seq,scores=as(quality(seq),"matrix"),colonies=1)
}
\keyword{utilities}
\keyword{dplot}
\keyword{manip}
